@@ -41,7 +41,7 @@ def format_traceback(extracted_tb,
                         function=None):
         """Return a pretty-printed editor shortcut."""
         return template.format(editor=editor,
-                               line_number=line_number,
+                               line_number=line_number or 0,
                                path=path,
                                function=function or u'',
                                hash_if_function=u'  # ' if function else u'',
@@ -79,8 +79,15 @@ def format_traceback(extracted_tb,
         # SyntaxErrors have a format different from other errors and include a
         # file path which looks out of place in our newly highlit, editor-
         # shortcutted world.
-        exc_lines = [format_shortcut(editor, exc_value.filename, exc_value.lineno)]
-        formatted_exception = format_exception_only(SyntaxError, exc_value)[1:]
+        if hasattr(exc_value, 'filename') and hasattr(exc_value, 'lineno'):
+            exc_lines = [format_shortcut(editor, exc_value.filename, exc_value.lineno)]
+            formatted_exception = format_exception_only(SyntaxError, exc_value)[1:]
+        else:
+            # The logcapture plugin may format exceptions as strings,
+            # stripping them of the full filename and lineno
+            exc_lines = []
+            formatted_exception = format_exception_only(SyntaxError, exc_value)
+            formatted_exception.append(u'(Try --nologcapture for a more detailed traceback)\n')
     else:
         exc_lines = []
         formatted_exception = format_exception_only(exc_type, exc_value)
